@@ -395,6 +395,26 @@ class Object(GetMembersMixin, SetMembersMixin, ObjectAliasMixin):
             kind = Kind(kind)
         return self.kind is kind
 
+    @property
+    def is_module(self) -> bool:
+        """Tell if this object is a module."""
+        return self.kind is Kind.MODULE  # noqa: DAR201
+
+    @property
+    def is_class(self) -> bool:
+        """Tell if this object is a class."""
+        return self.kind is Kind.CLASS  # noqa: DAR201
+
+    @property
+    def is_function(self) -> bool:
+        """Tell if this object is a function."""
+        return self.kind is Kind.FUNCTION  # noqa: DAR201
+
+    @property
+    def is_attribute(self) -> bool:
+        """Tell if this object is an attribute."""
+        return self.kind is Kind.ATTRIBUTE  # noqa: DAR201
+
     def has_labels(self, labels: set[str]) -> bool:
         """Tell if this object has all the given labels.
 
@@ -604,9 +624,13 @@ class Object(GetMembersMixin, SetMembersMixin, ObjectAliasMixin):
         if self.lineno and self.endlineno is None and sys.version_info < (3, 8):
             self.endlineno = self._endlineno
 
+        try:
+            lines = self.lines_collection[filepath]
+        except KeyError:
+            return []
         if self.lineno is None or self.endlineno is None:
-            return self.lines_collection[filepath]
-        return self.lines_collection[filepath][self.lineno - 1 : self.endlineno]
+            return lines
+        return lines[self.lineno - 1 : self.endlineno]
 
     @cached_property
     def source(self) -> str:
@@ -1095,6 +1119,15 @@ class Function(Object):
         self.returns: str | Name | Expression | None = returns
         self.decorators: list[Decorator] = decorators or []
 
+    @property
+    def annotation(self) -> str | Name | Expression | None:
+        """Return the return annotation.
+
+        Returns:
+            The function return annotation.
+        """
+        return self.returns
+
     def as_dict(self, **kwargs: Any) -> dict[str, Any]:  # type: ignore[override]
         """Return this function's data as a dictionary.
 
